The Array class (``zarr.core``)
===============================
.. module:: zarr.core

.. autoclass:: Array

    .. automethod:: __getitem__
    .. automethod:: __setitem__
    .. automethod:: get_basic_selection
    .. automethod:: set_basic_selection
    .. automethod:: get_mask_selection
    .. automethod:: set_mask_selection
    .. automethod:: get_coordinate_selection
    .. automethod:: set_coordinate_selection
    .. automethod:: get_orthogonal_selection
    .. automethod:: set_orthogonal_selection
    .. automethod:: digest
    .. automethod:: hexdigest
    .. automethod:: resize
    .. automethod:: append
    .. automethod:: view
    .. automethod:: astype
